@@ -12,19 +12,56 @@ Author: Heikki Toivonen
 import binascii
 import logging
 
-from M2Crypto import ASN1, BIO, EVP, m2, py27plus, six  # noqa
-if py27plus:
-    from typing import AnyStr, Optional  # noqa
+from M2Crypto import ASN1, BIO, EVP, m2, six  # noqa
+from typing import AnyStr, List, Optional  # noqa
 
 FORMAT_DER = 0
 FORMAT_PEM = 1
 
+if hasattr(m2, "VERIFY_ALLOW_PROXY_CERTS"):
+    verify_allow_proxy_certs = m2.VERIFY_ALLOW_PROXY_CERTS
+if hasattr(m2, "VERIFY_CB_ISSUER_CHECK"):
+    verify_cb_issuer_check = m2.VERIFY_CB_ISSUER_CHECK
+if hasattr(m2, "VERIFY_CHECK_SS_SIGNATURE"):
+    verify_check_ss_signature = m2.VERIFY_CHECK_SS_SIGNATURE
+if hasattr(m2, "VERIFY_CRL_CHECK"):
+    verify_crl_check = m2.VERIFY_CRL_CHECK
+if hasattr(m2, "VERIFY_CRL_CHECK_ALL"):
+    verify_crl_check_all = m2.VERIFY_CRL_CHECK_ALL
+if hasattr(m2, "VERIFY_EXPLICIT_POLICY"):
+    verify_explicit_policy = m2.VERIFY_EXPLICIT_POLICY
+if hasattr(m2, "VERIFY_EXTENDED_CRL_SUPPORT"):
+    verify_extended_crl_support = m2.VERIFY_EXTENDED_CRL_SUPPORT
+if hasattr(m2, "VERIFY_IGNORE_CRITICAL"):
+    verify_ignore_critical = m2.VERIFY_IGNORE_CRITICAL
+if hasattr(m2, "VERIFY_INHIBIT_ANY"):
+    verify_inhibit_any = m2.VERIFY_INHIBIT_ANY
+if hasattr(m2, "VERIFY_INHIBIT_MAP"):
+    verify_inhibit_map = m2.VERIFY_INHIBIT_MAP
+if hasattr(m2, "VERIFY_NO_ALT_CHAINS"):
+    verify_no_alt_chains = m2.VERIFY_NO_ALT_CHAINS
+if hasattr(m2, "VERIFY_NO_CHECK_TIME"):
+    verify_no_check_time = m2.VERIFY_NO_CHECK_TIME
+if hasattr(m2, "VERIFY_NOTIFY_POLICY"):
+    verify_notify_policy = m2.VERIFY_NOTIFY_POLICY
+if hasattr(m2, "VERIFY_PARTIAL_CHAIN"):
+    verify_partial_chain = m2.VERIFY_PARTIAL_CHAIN
+if hasattr(m2, "VERIFY_POLICY_CHECK"):
+    verify_policy_check = m2.VERIFY_POLICY_CHECK
+if hasattr(m2, "VERIFY_TRUSTED_FIRST"):
+    verify_trusted_first = m2.VERIFY_TRUSTED_FIRST
+if hasattr(m2, "VERIFY_USE_DELTAS"):
+    verify_use_deltas = m2.VERIFY_USE_DELTAS
+if hasattr(m2, "VERIFY_X509_STRICT"):
+    verify_x509_strict = m2.VERIFY_X509_STRICT
+
 log = logging.getLogger(__name__)
 
 
 class X509Error(ValueError):
     pass
 
+
 m2.x509_init(X509Error)
 
 V_OK = m2.X509_V_OK  # type: int
@@ -1004,11 +1041,17 @@ class X509_Store(object):
     add_cert = add_x509
 
     def set_flags(self, flags):
+        # type: (int) -> int
         """
         Set the verification flags for the X509Store
         Wrapper over OpenSSL X509_STORE_set_flags()
 
-        :param flags: verification parameters
+        :param flags: `VERIFICATION FLAGS` section of the
+                      X509_VERIFY_PARAM_set_flags man page has
+                      a complete description of values the flags
+                      parameter can take.
+                      Their M2Crypto equivalent is transformed following
+                      the pattern: "X509_V_FLAG_XYZ" -> lowercase("VERIFY_XYZ")
         """
         return m2.x509_store_set_flags(self.store, flags)
 
